@@ -9,7 +9,7 @@ use Config::JFDI;
 use Carp qw/croak/;
 use Data::Dumper;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 subtype MyConf => as 'HashRef';
 coerce 'MyConf'
@@ -184,7 +184,7 @@ sub _build_tree {
       my $parent      = $tree->{$node->{parent}};
       $node->{parent} = $parent;
 
-      $self->add($parent, $node);
+      $self->add($node, $parent);
   }
 }
 
@@ -517,7 +517,7 @@ sub del {
 
 # Inserts a node beneath the parent at the given position.
 sub add {
-  my ($self, $parent, $node, $position) = @_;
+  my ($self, $node, $parent, $position) = @_;
 
   $node->{id}     = $self->_last_node->{id} +1
       if ! defined $node->{id};
@@ -581,10 +581,10 @@ sub insert_before {
   my ($self, $sibling, $node) = @_;
 
   if ( ! defined $sibling->{$self->_position_field}) {
-      return $self->add($sibling->{parent}, $node, 1 );
+      return $self->add($node, $sibling->{parent}, 1 );
   }
 
-  return $self->add($sibling->{parent}, $node, $sibling->{$self->_position_field} );
+  return $self->add($node, $sibling->{parent}, $sibling->{$self->_position_field} );
 }
 
 
@@ -808,16 +808,16 @@ TreePath - Simple Tree Path!
 
 =cut
 
-=head2 add ($parent, $node)
+=head2 add ($node, $parent)
 
  # add the root
- $root = $tp->add(0, { name => '/'});
+ $root = $tp->add({ name => '/'}, 0);
 
  # add a node beneath the parent at the last position.
- $Z = $tp->add($parent, { name => 'Z' });
+ $Z = $tp->add({ name => 'Z' }, $parent);
 
  # or at given position
- $Z = $tp->add($parent, { name => 'Z', position => 2 });
+ $Z = $tp->add({ name => 'Z', position => 2 }, $parent);
 
 =cut
 
